@@ -35,16 +35,16 @@ func depFix(root string) error {
 	}
 	defer dir.Close()
 	for {
-		fis, err := dir.Readdir(1 << 10)
+		entries, err := dir.ReadDir(1 << 10)
 		if err != nil {
 			if err == io.EOF {
 				break
 			}
 			return err
 		}
-		for _, fi := range fis {
-			if fi.IsDir() {
-				if err = depFix(path.Join(root, fi.Name())); err != nil {
+		for _, entry := range entries {
+			if entry.IsDir() {
+				if err = depFix(path.Join(root, entry.Name())); err != nil {
 					return err
 				}
 			}
@@ -63,19 +63,19 @@ func depFix(root string) error {
 	defer dir.Close()
 	redoDirChanged := false
 	for {
-		fis, err := dir.Readdir(1 << 10)
+		entries, err := dir.ReadDir(1 << 10)
 		if err != nil {
 			if err == io.EOF {
 				break
 			}
 			return err
 		}
-		for _, fi := range fis {
-			if !strings.HasSuffix(fi.Name(), DepSuffix) {
+		for _, entry := range entries {
+			if !strings.HasSuffix(entry.Name(), DepSuffix) {
 				continue
 			}
-			tracef(CDebug, "depfix: checking %s/%s", root, fi.Name())
-			fdDepPath := path.Join(redoDir, fi.Name())
+			tracef(CDebug, "depfix: checking %s/%s", root, entry.Name())
+			fdDepPath := path.Join(redoDir, entry.Name())
 			fdDep, err := os.Open(fdDepPath)
 			if err != nil {
 				return err
@@ -104,7 +104,7 @@ func depFix(root string) error {
 				if dep == "" {
 					return ErrMissingTarget
 				}
-				tracef(CDebug, "depfix: checking %s/%s -> %s", root, fi.Name(), dep)
+				tracef(CDebug, "depfix: checking %s/%s -> %s", root, entry.Name(), dep)
 				theirInode, err := inodeFromRec(m)
 				if err != nil {
 					return err
@@ -115,7 +115,7 @@ func depFix(root string) error {
 					if os.IsNotExist(err) {
 						tracef(
 							CDebug, "depfix: %s/%s -> %s: not exists",
-							root, fi.Name(), dep,
+							root, entry.Name(), dep,
 						)
 						continue
 					}
@@ -129,7 +129,7 @@ func depFix(root string) error {
 				if inode.Size != theirInode.Size {
 					tracef(
 						CDebug, "depfix: %s/%s -> %s: size differs",
-						root, fi.Name(), dep,
+						root, entry.Name(), dep,
 					)
 					fd.Close()
 					continue
@@ -137,7 +137,7 @@ func depFix(root string) error {
 				if inode.Equals(theirInode) {
 					tracef(
 						CDebug, "depfix: %s/%s -> %s: inode is equal",
-						root, fi.Name(), dep,
+						root, entry.Name(), dep,
 					)
 					fd.Close()
 					continue
@@ -150,7 +150,7 @@ func depFix(root string) error {
 				if hsh != theirHsh {
 					tracef(
 						CDebug, "depfix: %s/%s -> %s: hash differs",
-						root, fi.Name(), dep,
+						root, entry.Name(), dep,
 					)
 					continue
 				}
@@ -163,7 +163,7 @@ func depFix(root string) error {
 				fieldses[len(fieldses)-1] = fields
 				tracef(
 					CDebug, "depfix: %s/%s -> %s: inode updated",
-					root, fi.Name(), dep,
+					root, entry.Name(), dep,
 				)
 				depChanged = true
 			}
@@ -172,14 +172,14 @@ func depFix(root string) error {
 				continue
 			}
 			redoDirChanged = true
-			fdDep, err = tempfile(redoDir, fi.Name())
+			fdDep, err = tempfile(redoDir, entry.Name())
 			if err != nil {
 				return err
 			}
 			defer fdDep.Close()
 			tracef(
 				CDebug, "depfix: %s/%s: tmp %s",
-				root, fi.Name(), fdDep.Name(),
+				root, entry.Name(), fdDep.Name(),
 			)
 			w := recfile.NewWriter(fdDep)
 			if _, err := w.WriteFields(fieldses[0]...); err != nil {
