@@ -108,18 +108,25 @@ func buildDependants(tgts []string) map[string]struct{} {
 	Level = 1
 	tracef(CDebug, "building %d alwayses: %v", len(seen), seen)
 	errs := make(chan error, len(seen))
+	ok := true
+	okChecker := make(chan struct{})
+	go func() {
+		for err := range errs {
+			ok = isOkRun(err) && ok
+		}
+		close(okChecker)
+	}()
 	for tgt := range seen {
-		if err := runScript(tgt, errs, false); err != nil {
+		if err := runScript(tgt, errs, false, false); err != nil {
 			tracef(CErr, "always run error: %s, skipping dependants", err)
+			Jobs.Wait()
+			close(errs)
 			return nil
 		}
 	}
-	ok := true
-	for i := 0; i < len(seen); i++ {
-		ok = isOkRun(<-errs) && ok
-	}
 	Jobs.Wait()
 	close(errs)
+	<-okChecker
 	if !ok {
 		tracef(CDebug, "alwayses failed, skipping dependants")
 		return nil
@@ -144,9 +151,16 @@ RebuildDeps:
 
 	tracef(CDebug, "building %d dependant targets: %v", len(queue), queue)
 	errs = make(chan error, len(queue))
+	okChecker = make(chan struct{})
 	jobs := 0
 	queueSrc = []string{}
-	for tgt, _ := range queue {
+	go func() {
+		for err := range errs {
+			ok = isOkRun(err) && ok
+		}
+		close(okChecker)
+	}()
+	for tgt := range queue {
 		ood, err := isOODWithTrace(Cwd, tgt, 0, seen)
 		if err != nil {
 			tracef(CErr, "dependant error: %s, skipping dependants", err)
@@ -155,7 +169,7 @@ RebuildDeps:
 		if !ood {
 			continue
 		}
-		if err := runScript(tgt, errs, false); err != nil {
+		if err := runScript(tgt, errs, false, false); err != nil {
 			tracef(CErr, "dependant error: %s, skipping dependants", err)
 			return nil
 		}
@@ -163,15 +177,13 @@ RebuildDeps:
 		seen[tgt] = struct{}{}
 		jobs++
 	}
-	for i := 0; i < jobs; i++ {
-		ok = isOkRun(<-errs) && ok
-	}
+	Jobs.Wait()
+	close(errs)
+	<-okChecker
 	if !ok {
 		tracef(CDebug, "dependants failed, skipping them")
 		return nil
 	}
-	Jobs.Wait()
-	close(errs)
 	if jobs == 0 {
 		return seen
 	}
@@ -195,17 +207,24 @@ func ifchange(tgts []string, forced, traced bool) (bool, error) {
 	if !IsTopRedo {
 		defer jsAcquire("ifchange exiting")
 	}
-	defer Jobs.Wait()
 	seen := buildDependants(tgts)
 	if seen == nil {
+		Jobs.Wait()
 		return false, nil
 	}
 	oodTgtsClear()
 	tracef(CDebug, "building %d targets: %v", len(tgts), tgts)
-	jobs := 0
-	errs := make(chan error, len(tgts))
 	var ood bool
 	var err error
+	ok := true
+	okChecker := make(chan struct{})
+	errs := make(chan error, len(tgts))
+	go func() {
+		for err := range errs {
+			ok = isOkRun(err) && ok
+		}
+		close(okChecker)
+	}()
 	for _, tgt := range tgts {
 		if _, ok := seen[tgt]; ok {
 			tracef(CDebug, "%s was already build as a dependant", tgt)
@@ -215,6 +234,8 @@ func ifchange(tgts []string, forced, traced bool) (bool, error) {
 		if !forced {
 			ood, err = isOODWithTrace(Cwd, tgt, 0, seen)
 			if err != nil {
+				Jobs.Wait()
+				close(errs)
 				return false, err
 			}
 		}
@@ -225,14 +246,14 @@ func ifchange(tgts []string, forced, traced bool) (bool, error) {
 			tracef(CDebug, "%s is source, not redoing", tgt)
 			continue
 		}
-		if err = runScript(tgt, errs, traced); err != nil {
+		if err = runScript(tgt, errs, forced, traced); err != nil {
+			Jobs.Wait()
+			close(errs)
 			return false, err
 		}
-		jobs++
-	}
-	ok := true
-	for ; jobs > 0; jobs-- {
-		ok = isOkRun(<-errs) && ok
 	}
+	Jobs.Wait()
+	close(errs)
+	<-okChecker
 	return ok, nil
 }
