@@ -298,7 +298,7 @@ func main() {
 		}
 	}
 
-	if cmdName == CmdNameRedo || cmdName == CmdNameRedoIfchange {
+	if cmdName == CmdNameRedo {
 		statusInit()
 	}
 
