@@ -137,9 +137,15 @@ func isOOD(cwd, tgtOrig string, level int, seen map[string]struct{}) (bool, erro
 	depPath := path.Join(cwd, RedoDir, tgt+DepSuffix)
 	fdDep, err := os.Open(depPath)
 	if err != nil {
-		tracef(CDebug, "ood: %s%s -> no dep: %s", indent, tgtOrig, depPath)
-		OODCache[path.Join(cwd, tgt)] = true
-		return true, nil
+		if isSrc(cwd, tgt) {
+			ood = false
+			tracef(CDebug, "ood: %s%s -> is source", indent, tgtOrig)
+		} else {
+			ood = true
+			tracef(CDebug, "ood: %s%s -> no dep: %s", indent, tgtOrig, depPath)
+		}
+		OODCache[path.Join(cwd, tgt)] = ood
+		return ood, nil
 	}
 	depInfo, err := depRead(fdDep)
 	fdDep.Close()
